@@ -13,7 +13,7 @@ spread.level.plot.default<-function(x, by, robust.line=any("MASS"==.packages(all
         main=paste("Spread-Level Plot for", deparse(substitute(x)), 
         "by", deparse(substitute(by))), col=palette()[2], pch=1, lwd=2, ...)
     {
-    #last modified 20 Feb 2002 by J. Fox
+    #last modified 23 Feb 2003 by J. Fox
     good<-!(is.na(x) | is.na(by))
     if (sum(good) != length(x)) {
         warning("NAs ignored")
@@ -43,7 +43,7 @@ spread.level.plot.default<-function(x, by, robust.line=any("MASS"==.packages(all
     pos<-ifelse(medians>median(medians), 2, 4)
     text(medians, spreads, as.character(values), pos=pos, ...)
     if (robust.line){
-        if (!require("MASS", quietly=TRUE)) stop("MASS package not available")
+        if (!require("MASS")) stop("MASS package not available")
         mod<-rlm(log(spreads)~log(medians))
         }
         else mod<-lm(log(spreads)~log(medians), ...)
@@ -66,7 +66,7 @@ spread.level.plot.lm<-function(x, start=0,
         main=paste("Spread-Level Plot for", deparse(substitute(x))),
         pch=1, col=palette()[2], lwd=2, ...)
     {
-    #last modified 20 Feb 2002 by J. Fox
+    #last modified 23 Feb 2003 by J. Fox
     resid<-na.omit(abs(rstudent(x)))
     fitval<-na.omit(fitted.values(x))
     min<-min(fitval)
@@ -79,7 +79,7 @@ spread.level.plot.lm<-function(x, start=0,
     plot(fitval+start, resid, log="xy", main=main, xlab=xlab, ylab=ylab, 
         las=las, col=col, pch=pch, ...)
     if (robust.line){
-        if (!require("MASS", quietly=TRUE)) stop("MASS package not available")
+        if (!require("MASS")) stop("MASS package not available")
         mod<-rlm(log(resid)~log(fitval+start))
         }
         else mod<-lm(log(resid)~log(fitval+start), ...)
